@@ -9,7 +9,7 @@ site_package_dir=site.getsitepackages()
 if len(site_package_dir) == 1:
     os.chdir(site_package_dir)
     site_package_dir=' '.join(site_package_dir)
-    logo_file_path=os.path.join(site_package_dir, "quanturf", "quanturf_logo.js")
+    logo_file_path=os.path.join(site_package_dir, "quanturf", "quanturf_logo.py")
     logo_file_path = logo_file_path.replace(os.sep, '/')
     logo_file=open(logo_file_path,"r")
     logo_code=logo_file.read()
@@ -25,7 +25,7 @@ if len(site_package_dir) == 1:
 
 if len(site_package_dir) >= 2:
     os.chdir(site_package_dir[1])
-    logo_file_path=os.path.join(site_package_dir[1], "quanturf", "quanturf_logo.js")
+    logo_file_path=os.path.join(site_package_dir[1], "quanturf", "quanturf_logo.py")
     logo_file_path = logo_file_path.replace(os.sep, '/')
     logo_file=open(logo_file_path,"r")
     logo_code=logo_file.read()
